# Comparison to other Python NLP packages

NOTE: the implementation currently supports the representation of 
documents, annotations and other elements relevant for NLP but 
not actual processing resources and models. The comparison is 
therefore restricted to just those parts that are implemented in
`gatenlp`.

## Spacy

TBD

## NLTK

TBD
